ApiErrorExt

Trait ApiErrorExt 

pub trait ApiErrorExt {
    type Error: Debug + From<ApiError>;
}
Extends the runtime api traits with an associated error type. This trait is given as super trait to every runtime api trait.

Required Associated Types

type Error: Debug + From<ApiError>

Error type used by the runtime apis.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors